@@ -38,7 +38,7 @@ EXAMPLE
 import functools
 import xmod
 
-__version__ = '0.9.2'
+__version__ = '1.0.0'
 __all__ = 'abbrev', 'NONE'
 
 NONE = object()
@@ -52,7 +52,7 @@ def abbrev(abbrevs, key=NONE, default=NONE, multi=False, unique=True):
 
     ARGUMENTS
       abbrevs:
-        A dictionary with string keys
+        A dictionary with string keys or a sequence of strings
 
       key:
         An abbreviated key to look up in `abbrevs`,
@@ -79,6 +79,9 @@ def abbrev(abbrevs, key=NONE, default=NONE, multi=False, unique=True):
             abbrev, abbrevs, default=default, multi=multi, unique=unique
         )
 
+    if not isinstance(abbrevs, dict):
+        abbrevs = {i: i for i in abbrevs}
+
     r = abbrevs.get(key, NONE)
     if r is not NONE:
         return (r,) if multi else r
